@@ -125,7 +125,7 @@ def cli(
             do_where(state.project, bare=True)
             return 0
         elif py:
-            do_py(state.project, ctx=ctx)
+            do_py(state.project, ctx=ctx, bare=True)
             return 0
         # --support was passed...
         elif support:
@@ -258,6 +258,7 @@ def upgrade(state, **kwargs):
         dev=state.installstate.dev,
         system=state.system,
         lock_only=state.installstate.lock_only,
+        extra_pip_args=state.installstate.extra_pip_args,
     )
 
 
@@ -284,15 +285,18 @@ def uninstall(ctx, state, all_dev=False, all=False, **kwargs):
     """Uninstalls a provided package and removes it from Pipfile."""
     from pipenv.routines.uninstall import do_uninstall
 
+    pre = state.installstate.pre
+
     retcode = do_uninstall(
         state.project,
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
         python=state.python,
         system=state.system,
-        lock=True,
+        lock=False,
         all_dev=all_dev,
         all=all,
+        pre=pre,
         pypi_mirror=state.pypi_mirror,
         categories=state.installstate.categories,
         ctx=ctx,
@@ -364,16 +368,14 @@ def lock(ctx, state, **kwargs):
     default=False,
     help="Always spawn a sub-shell, even if one is already spawned.",
 )
+@option(
+    "--quiet", is_flag=True, help="Quiet standard output, except vulnerability report."
+)
 @argument("shell_args", nargs=-1)
 @pypi_mirror_option
 @python_option
 @pass_state
-def shell(
-    state,
-    fancy=False,
-    shell_args=None,
-    anyway=False,
-):
+def shell(state, fancy=False, shell_args=None, anyway=False, quiet=False):
     """Spawns a shell within the virtualenv."""
     from pipenv.routines.shell import do_shell
 
@@ -390,8 +392,12 @@ def shell(
             sys.exit(1)
     # Load .env file.
     load_dot_env(state.project)
-    # Use fancy mode for Windows.
-    if os.name == "nt":
+    # Use fancy mode for Windows or pwsh on *nix.
+    if (
+        os.name == "nt"
+        or (os.environ.get("PIPENV_SHELL") or "").split(os.path.sep)[-1] == "pwsh"
+        or (os.environ.get("SHELL") or "").split(os.path.sep)[-1] == "pwsh"
+    ):
         fancy = True
     do_shell(
         state.project,
@@ -399,6 +405,7 @@ def shell(
         fancy=fancy,
         shell_args=shell_args,
         pypi_mirror=state.pypi_mirror,
+        quiet=quiet,
     )
 
 
@@ -520,6 +527,7 @@ def check(
         output=output,
         key=key,
         quiet=quiet,
+        verbose=state.verbose,
         exit_code=exit_code,
         policy_file=policy_file,
         save_json=save_json,
@@ -639,16 +647,14 @@ def run_open(state, module, *args, **kwargs):
 @pass_context
 def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
     """Installs all packages specified in Pipfile.lock."""
-    from pipenv.routines.install import do_sync
+    from pipenv.routines.sync import do_sync
 
     retcode = do_sync(
         state.project,
         dev=state.installstate.dev,
         python=state.python,
         bare=bare,
-        user=user,
         clear=state.clear,
-        unused=unused,
         pypi_mirror=state.pypi_mirror,
         system=state.system,
         extra_pip_args=state.installstate.extra_pip_args,
@@ -737,9 +743,21 @@ def verify(state):
     default="",
     help="Only add requirement of the specified categories.",
 )
+@option(
+    "--from-pipfile",
+    is_flag=True,
+    default=False,
+    help="Only include dependencies from Pipfile.",
+)
 @pass_state
 def requirements(
-    state, dev=False, dev_only=False, hash=False, exclude_markers=False, categories=""
+    state,
+    dev=False,
+    dev_only=False,
+    hash=False,
+    exclude_markers=False,
+    categories="",
+    from_pipfile=False,
 ):
     from pipenv.routines.requirements import generate_requirements
 
@@ -750,6 +768,7 @@ def requirements(
         include_hashes=hash,
         include_markers=not exclude_markers,
         categories=categories,
+        from_pipfile=from_pipfile,
     )
 
 
@@ -757,7 +776,7 @@ if __name__ == "__main__":
     cli()
 
 
-def do_py(project, ctx=None, system=False):
+def do_py(project, ctx=None, system=False, bare=False):
     if not project.virtualenv_exists:
         err.print(
             "[red]No virtualenv has been created for this project[/red] "
@@ -767,6 +786,7 @@ def do_py(project, ctx=None, system=False):
         ctx.abort()
 
     try:
-        console.print(project._which("python", allow_global=system))
+        (print if bare else console.print)(project._which("python", allow_global=system))
     except AttributeError:
         console.print("No project found!", style="red")
+        ctx.abort()
