@@ -222,7 +222,7 @@ class Setting:
             _spinners.SPINNERS[None] = {"interval": 80, "frames": "   "}
             self.PIPENV_SPINNER = None
         else:
-            pipenv_spinner = "dots" if not os.name == "nt" else "bouncingBar"
+            pipenv_spinner = "bouncingBar" if os.name == "nt" else "dots"
             self.PIPENV_SPINNER = get_from_env(
                 "SPINNER", check_for_negation=False, default=pipenv_spinner
             )
@@ -289,11 +289,22 @@ class Setting:
         Default is 120 seconds, an arbitrary number that seems to work.
         """
 
+        self.PIPENV_REQUESTS_TIMEOUT = int(
+            get_from_env("REQUESTS_TIMEOUT", check_for_negation=False, default=10)
+        )
+        """Timeout setting for requests.
+
+        Default is 10 seconds.
+
+        For more information on the role of Timeout in Requests, see
+        [Requests docs](https://requests.readthedocs.io/en/latest/user/advanced/#timeouts).
+        """
+
         self.PIPENV_VENV_IN_PROJECT = get_from_env("VENV_IN_PROJECT")
         """ When set True, will create or use the ``.venv`` in your project directory.
         When Set False, will ignore the .venv in your project directory even if it exists.
         If unset (default), will use the .venv of project directory should it exist, otherwise
-          will create new virtual environments in a global location.
+        will create new virtual environments in a global location.
         """
 
         self.PIPENV_VERBOSE = bool(get_from_env("VERBOSE", check_for_negation=False))
@@ -397,10 +408,10 @@ class Setting:
         del self.PIPENV_VERBOSE
 
     def is_verbose(self, threshold=1):
-        return self.PIPENV_VERBOSITY >= threshold
+        return threshold <= self.PIPENV_VERBOSITY
 
     def is_quiet(self, threshold=-1):
-        return self.PIPENV_VERBOSITY <= threshold
+        return threshold >= self.PIPENV_VERBOSITY
 
 
 def is_using_venv() -> bool:
