@@ -21,6 +21,8 @@ try:
 except ImportError:
     from pipenv.vendor import tomli as toml
 
+import contextlib
+
 from pipenv.cmdparse import Script
 from pipenv.environment import Environment
 from pipenv.environments import Setting, is_in_virtualenv, normalize_pipfile_path
@@ -30,7 +32,6 @@ from pipenv.patched.pip._internal.exceptions import ConfigurationError
 from pipenv.patched.pip._internal.models.link import Link
 from pipenv.patched.pip._internal.req.req_install import InstallRequirement
 from pipenv.patched.pip._internal.utils.hashes import FAVORITE_HASH
-from pipenv.patched.pip._vendor import pkg_resources
 from pipenv.utils import err
 from pipenv.utils.constants import is_type_checking
 from pipenv.utils.dependencies import (
@@ -61,7 +62,6 @@ from pipenv.utils.shell import (
     find_windows_executable,
     get_workon_home,
     is_virtual_environment,
-    load_path,
     looks_like_dir,
     safe_expandvars,
     system_which,
@@ -76,6 +76,11 @@ except ImportError:
     # eventually distlib will remove cached property when they drop Python3.7
     from pipenv.patched.pip._vendor.distlib.util import cached_property
 
+if sys.version_info < (3, 10):
+    from pipenv.vendor import importlib_metadata
+else:
+    import importlib.metadata as importlib_metadata
+
 if is_type_checking():
     from typing import Dict, List, Union
 
@@ -208,10 +213,8 @@ class Project:
 
         # Hack to skip this during pipenv run, or -r.
         if ("run" not in sys.argv) and chdir:
-            try:
+            with contextlib.suppress(TypeError, AttributeError):
                 os.chdir(self.project_directory)
-            except (TypeError, AttributeError):
-                pass
 
     def path_to(self, p: str) -> str:
         """Returns the absolute path to a given relative path."""
@@ -236,6 +239,8 @@ class Project:
             return ["packages", "dev-packages"] + list(package_categories)
 
     def get_requests_session_for_source(self, source):
+        if not (source and source.get("name")):
+            return None
         if self.sessions.get(source["name"]):
             session = self.sessions[source["name"]]
         else:
@@ -243,6 +248,7 @@ class Project:
                 self.s.PIPENV_MAX_RETRIES,
                 source.get("verify_ssl", True),
                 cache_dir=self.s.PIPENV_CACHE_DIR,
+                source=source.get("url"),
             )
             self.sessions[source["name"]] = session
         return session
@@ -267,10 +273,12 @@ class Project:
     def get_hashes_from_pypi(self, ireq, source):
         pkg_url = f"https://pypi.org/pypi/{ireq.name}/json"
         session = self.get_requests_session_for_source(source)
+        if not session:
+            return None
         try:
             collected_hashes = set()
             # Grab the hashes from the new warehouse API.
-            r = session.get(pkg_url, timeout=10)
+            r = session.get(pkg_url, timeout=self.s.PIPENV_REQUESTS_TIMEOUT)
             api_releases = r.json()["releases"]
             cleaned_releases = {}
             for api_version, api_info in api_releases.items():
@@ -292,17 +300,16 @@ class Project:
             return None
 
     def get_hashes_from_remote_index_urls(self, ireq, source):
-        pkg_url = f"{source['url']}/{ireq.name}/"
+        normalized_name = normalize_name(ireq.name)
+        url_name = normalized_name.replace(".", "-")
+        pkg_url = f"{source['url']}/{url_name}/"
         session = self.get_requests_session_for_source(source)
+
         try:
             collected_hashes = set()
-            # Grab the hashes from the new warehouse API.
-            response = session.get(pkg_url, timeout=10)
-            # Create an instance of the parser
+            response = session.get(pkg_url, timeout=self.s.PIPENV_REQUESTS_TIMEOUT)
             parser = PackageIndexHTMLParser()
-            # Feed the HTML to the parser
             parser.feed(response.text)
-            # Extract hrefs
             hrefs = parser.urls
 
             version = ""
@@ -310,20 +317,48 @@ class Project:
                 spec = next(iter(s for s in ireq.specifier), None)
                 if spec:
                     version = spec.version
+
+            # We'll check if the href looks like a version-specific page (i.e., ends with '/')
             for package_url in hrefs:
-                if version in parse.unquote(package_url):
+                parsed_url = parse.urlparse(package_url)
+                if version in parsed_url.path and parsed_url.path.endswith("/"):
+                    # This might be a version-specific page. Fetch and parse it
+                    version_url = urljoin(pkg_url, package_url)
+                    version_response = session.get(
+                        version_url, timeout=self.s.PIPENV_REQUESTS_TIMEOUT
+                    )
+                    version_parser = PackageIndexHTMLParser()
+                    version_parser.feed(version_response.text)
+                    version_hrefs = version_parser.urls
+
+                    # Process these new hrefs as potential wheels
+                    for v_package_url in version_hrefs:
+                        url_params = parse.urlparse(v_package_url).fragment
+                        params_dict = parse.parse_qs(url_params)
+                        if params_dict.get(FAVORITE_HASH):
+                            collected_hashes.add(params_dict[FAVORITE_HASH][0])
+                        else:  # Fallback to downloading the file to obtain hash
+                            v_package_full_url = urljoin(version_url, v_package_url)
+                            link = Link(v_package_full_url)
+                            file_hash = self.get_file_hash(session, link)
+                            if file_hash:
+                                collected_hashes.add(file_hash)
+                elif version in parse.unquote(package_url):
+                    # Process the current href as a potential wheel from the main page
                     url_params = parse.urlparse(package_url).fragment
                     params_dict = parse.parse_qs(url_params)
                     if params_dict.get(FAVORITE_HASH):
                         collected_hashes.add(params_dict[FAVORITE_HASH][0])
                     else:  # Fallback to downloading the file to obtain hash
-                        package_url = urljoin(source["url"], package_url)
-                        link = Link(package_url)
+                        package_full_url = urljoin(pkg_url, package_url)
+                        link = Link(package_full_url)
                         file_hash = self.get_file_hash(session, link)
                         if file_hash:
                             collected_hashes.add(file_hash)
+
             return self.prepend_hash_types(collected_hashes, FAVORITE_HASH)
-        except (ValueError, KeyError, ConnectionError):
+
+        except Exception:
             if self.s.is_verbose():
                 click.echo(
                     "{}: Error generating hash for {}".format(
@@ -399,16 +434,12 @@ class Project:
 
         dot_venv = os.path.join(self.project_directory, ".venv")
 
-        # If there's no .venv in project root, set location based on config.
-        if not os.path.exists(dot_venv):
+        # If there's no .venv in project root or it is a folder, set location based on config.
+        if not os.path.exists(dot_venv) or os.path.isdir(dot_venv):
             if self.is_venv_in_project():
                 return dot_venv
             return str(get_workon_home().joinpath(self.virtualenv_name))
 
-        # If .venv in project root is a directory, use it.
-        if os.path.isdir(dot_venv):
-            return dot_venv
-
         # Now we assume .venv in project root is a file. Use its content.
         with open(dot_venv) as f:
             name = f.read().strip()
@@ -424,18 +455,13 @@ class Project:
             return path.absolute().as_posix()
         return str(get_workon_home().joinpath(name))
 
-    @property
-    def working_set(self) -> pkg_resources.WorkingSet:
-        sys_path = load_path(self.which("python"))
-        return pkg_resources.WorkingSet(sys_path)
-
     @property
     def installed_packages(self):
         return self.environment.get_installed_packages()
 
     @property
-    def installed_package_names(self) -> list[str]:
-        return get_canonical_names([pkg.key for pkg in self.installed_packages])
+    def installed_package_names(self):
+        return get_canonical_names([pkg.name for pkg in self.installed_packages])
 
     @property
     def lockfile_package_names(self) -> dict[str, set[str]]:
@@ -488,7 +514,7 @@ class Project:
             self._environment = self.get_environment(allow_global=allow_global)
         return self._environment
 
-    def get_outdated_packages(self) -> list[pkg_resources.Distribution]:
+    def get_outdated_packages(self) -> list[importlib_metadata.Distribution]:
         return self.environment.get_outdated_packages(pre=self.pipfile.get("pre", False))
 
     @classmethod
@@ -999,7 +1025,7 @@ class Project:
         return sources
 
     def get_default_index(self):
-        return self.pipfile_sources()[0]
+        return self.populate_source(self.pipfile_sources()[0])
 
     def get_index_by_name(self, index_name):
         for source in self.pipfile_sources():
@@ -1079,17 +1105,38 @@ class Project:
         if section is None:
             section = {}
         package_name = pep423_name(package_name)
-        for name in section.keys():
+        for name in section:
             if pep423_name(name) == package_name:
                 return name
         return None
 
+    def _sort_category(self, category):
+        # toml tables won't maintain sorted dictionary order
+        # so construct the table in the order that we need
+        table = tomlkit.table()
+        for key, value in sorted(category.items()):
+            table.add(key, value)
+
+        return table
+
     def remove_package_from_pipfile(self, package_name, category):
         # Read and append Pipfile.
         name = self.get_package_name_in_pipfile(package_name, category=category)
         p = self.parsed_pipfile
         if name:
             del p[category][name]
+            if self.settings.get("sort_pipfile"):
+                p[category] = self._sort_category(p[category])
+            self.write_toml(p)
+            return True
+        return False
+
+    def reset_category_in_pipfile(self, category):
+        # Read and append Pipfile.
+        p = self.parsed_pipfile
+        if category:
+            del p[category]
+            p[category] = {}
             self.write_toml(p)
             return True
         return False
@@ -1107,11 +1154,17 @@ class Project:
         self.write_toml(parsed)
 
     def generate_package_pipfile_entry(self, package, pip_line, category=None):
+        """Generate a package entry from pip install line
+        given the installreq package and the pip line that generated it.
+        """
         # Don't re-capitalize file URLs or VCSs.
         if not isinstance(package, InstallRequirement):
-            package = expansive_install_req_from_line(package.strip())
+            package, req_name = expansive_install_req_from_line(package.strip())
+        else:
+            _, req_name = expansive_install_req_from_line(pip_line.strip())
 
-        req_name = determine_package_name(package)
+        if req_name is None:
+            req_name = determine_package_name(package)
         path_specifier = determine_path_specifier(package)
         vcs_specifier = determine_vcs_specifier(package)
         name = self.get_package_name_in_pipfile(req_name, category=category)
@@ -1146,7 +1199,8 @@ class Project:
                     else:
                         vcs_part = pip_line
                     vcs_parts = vcs_part.rsplit("@", 1)
-                    entry["ref"] = vcs_parts[1].split("#", 1)[0].strip()
+                    if len(vcs_parts) > 1:
+                        entry["ref"] = vcs_parts[1].split("#", 1)[0].strip()
                     entry[vcs] = vcs_parts[0].strip()
 
                     # Check and extract subdirectory fragment
@@ -1193,13 +1247,20 @@ class Project:
 
         p[category][normalized_name] = entry
 
+        if self.settings.get("sort_pipfile"):
+            p[category] = self._sort_category(p[category])
+
         # Write Pipfile.
         self.write_toml(p)
         return newly_added, category, normalized_name
 
     def src_name_from_url(self, index_url):
-        name, _, tld_guess = urllib.parse.urlsplit(index_url).netloc.rpartition(".")
-        src_name = name.replace(".", "")
+        location = urllib.parse.urlsplit(index_url).netloc
+        if "." in location:
+            name, _, tld_guess = location.rpartition(".")
+        else:
+            name = location
+        src_name = name.replace(".", "").replace(":", "")
         try:
             self.get_source(name=src_name)
         except SourceNotFound:
@@ -1218,11 +1279,10 @@ class Project:
         try:
             source = self.get_source(url=index)
         except SourceNotFound:
-            try:
+            with contextlib.suppress(SourceNotFound):
                 source = self.get_source(name=index)
-            except SourceNotFound:
-                pass
-        if source is not None:
+
+        if source is not None and source.get("name"):
             return source["name"]
         source = {"url": index, "verify_ssl": verify_ssl}
         source["name"] = self.src_name_from_url(index)
@@ -1312,7 +1372,7 @@ class Project:
         """
         # Casing for section.
         changed_values = False
-        unknown_names = [k for k in section.keys() if k not in set(self.proper_names)]
+        unknown_names = [k for k in section if k not in set(self.proper_names)]
         # Replace each package with proper casing.
         for dep in unknown_names:
             try:
