@@ -1,11 +1,15 @@
 import pytest
 
+from .conftest import DEFAULT_PRIVATE_PYPI_SERVER
+
+
 @pytest.mark.urls
 @pytest.mark.extras
 @pytest.mark.install
-def test_install_uri_with_extras(pipenv_instance_private_pypi):
-    file_uri = "http://localhost:8080/packages/plette/plette-0.2.2-py2.py3-none-any.whl"
-    with pipenv_instance_private_pypi() as p:
+def test_install_uri_with_extras(pipenv_instance_pypi):
+    server = DEFAULT_PRIVATE_PYPI_SERVER.replace("/simple", "")
+    file_uri = f"{server}/packages/plette/plette-0.2.2-py2.py3-none-any.whl"
+    with pipenv_instance_pypi() as p:
         with open(p.pipfile_path, 'w') as f:
             contents = f"""
 [[source]]
@@ -20,3 +24,4 @@ plette = {{file = "{file_uri}", extras = ["validation"]}}
         c = p.pipenv("install")
         assert c.returncode == 0
         assert "plette" in p.lockfile["default"]
+        assert "cerberus" in p.lockfile["default"]
