@@ -90,11 +90,8 @@ def test_uninstall_all_local_files(pipenv_instance_private_pypi, testsroot):
         c = p.pipenv(f"install {file_uri}")
         assert c.returncode == 0
         c = p.pipenv("uninstall --all")
-        assert c.returncode == 0
-        assert "tablib" in c.stdout
-        # Uninstall --all is not supposed to remove things from the pipfile
-        # Note that it didn't before, but that instead local filenames showed as hashes
-        assert "tablib" in p.pipfile["packages"]
+        assert "tablib" not in p.pipfile["packages"]
+        assert "tablib" not in p.lockfile["default"]
 
 
 @pytest.mark.install
@@ -218,7 +215,7 @@ def test_uninstall_category_with_shared_requirement(pipenv_instance_pypi):
         c = p.pipenv("install")
         assert c.returncode == 0
 
-        c = p.pipenv("uninstall six --categories packages")
+        c = p.pipenv("uninstall six --categories default")
         assert c.returncode == 0
 
         assert "six" in p.lockfile["prereq"]
